@@ -79,7 +79,7 @@ impl AccountsDataMeter {
     /// return an error and *do not* consume more accounts data space.
     pub fn consume(&mut self, amount: i64) -> Result<(), InstructionError> {
         if amount > self.remaining() as i64 {
-            return Err(InstructionError::MaxAccountsDataSizeExceeded);
+            return Err(InstructionError::AccountsDataBudgetExceeded);
         }
         self.consume_unchecked(amount);
         Ok(())
